<?php
/*----------------------------------------------------+
| LIBRARY MANAGEMENT SYSTEM
|-----------------------------------------------------+
| A LIBRARY RESOURCE MANAGER
| BY EDAN BOY PEDRAGOSA "alias" HACKERSOFT
| Web: http://hackersoft.ath.cx/dev/
| email: edan@niva-is.net
|----------------------------------------------------+
| Released under the terms and conditions of
| the GNU General Public License
+----------------------------------------------------*/

function datediff($interval, $datefrom, $dateto, $using_timestamps = false) {
  /*
    $interval can be:
    yyyy - Number of full years
    q - Number of full quarters
    m - Number of full months
    y - Difference between day numbers
      (eg 1st Jan 2004 is "1", the first day. 2nd Feb 2003 is "33". The datediff is "-32".)
    d - Number of full days
    w - Number of full weekdays
    ww - Number of full weeks
    h - Number of full hours
    n - Number of full minutes
    s - Number of full seconds (default)
  */
  
  if (!$using_timestamps) {
    $datefrom = strtotime($datefrom, 0);
    $dateto = strtotime($dateto, 0);
  }
  $difference = $dateto - $datefrom; // Difference in seconds
  
  switch($interval) {
  
    case 'yyyy': // Number of full years

      $years_difference = floor($difference / 31536000);
      if (mktime(date("H", $datefrom), date("i", $datefrom), date("s", $datefrom), date("n", $datefrom), date("j", $datefrom), date("Y", $datefrom)+$years_difference) > $dateto) {
        $years_difference--;
      }
      if (mktime(date("H", $dateto), date("i", $dateto), date("s", $dateto), date("n", $dateto), date("j", $dateto), date("Y", $dateto)-($years_difference+1)) > $datefrom) {
        $years_difference++;
      }
      $datediff = $years_difference;
      break;

    case "q": // Number of full quarters

      $quarters_difference = floor($difference / 8035200);
      while (mktime(date("H", $datefrom), date("i", $datefrom), date("s", $datefrom), date("n", $datefrom)+($quarters_difference*3), date("j", $dateto), date("Y", $datefrom)) < $dateto) {
        $months_difference++;
      }
      $quarters_difference--;
      $datediff = $quarters_difference;
      break;

    case "m": // Number of full months

      $months_difference = floor($difference / 2678400);
      while (mktime(date("H", $datefrom), date("i", $datefrom), date("s", $datefrom), date("n", $datefrom)+($months_difference), date("j", $dateto), date("Y", $datefrom)) < $dateto) {
        $months_difference++;
      }
      $months_difference--;
      $datediff = $months_difference;
      break;

    case 'y': // Difference between day numbers

      $datediff = date("z", $dateto) - date("z", $datefrom);
      break;

    case "d": // Number of full days

      $datediff = floor($difference / 86400);
      break;

    case "w": // Number of full weekdays

      $days_difference = floor($difference / 86400);
      $weeks_difference = floor($days_difference / 7); // Complete weeks
      $first_day = date("w", $datefrom);
      $days_remainder = floor($days_difference % 7);
      $odd_days = $first_day + $days_remainder; // Do we have a Saturday or Sunday in the remainder?
      if ($odd_days > 7) { // Sunday
        $days_remainder--;
      }
      if ($odd_days > 6) { // Saturday
        $days_remainder--;
      }
      $datediff = ($weeks_difference * 5) + $days_remainder;
      break;

    case "ww": // Number of full weeks

      $datediff = floor($difference / 604800);
      break;

    case "h": // Number of full hours

      $datediff = floor($difference / 3600);
      break;

    case "n": // Number of full minutes

      $datediff = floor($difference / 60);
      break;

    default: // Number of full seconds (default)

      $datediff = $difference;
      break;
  }    

  return $datediff;

}

function ComputeDueDate($LoanValue,$LoanDuration,$TimeBasis){
	if ($LoanDuration == "Hour") {
		$DueDate = ($LoanValue * 3600) + $TimeBasis;
	} elseif ($LoanDuration == "Day") {
		$DueDate = ($LoanValue * 86400) + $TimeBasis;
	} elseif ($LoanDuration == "Week") {
		$DueDate = ($LoanValue * 86400 * 7) + $TimeBasis;
	} elseif ($LoanDuration == "Month") {
		$DueDate = ($LoanValue * 86400 * 30) + $TimeBasis;
	} elseif ($LoanDuration == "Year") {
		$DueDate = ($LoanValue * 86400 * 365) + $TimeBasis;
	}
		return $DueDate;
}//function ends here


function UpdateBorrowedCopies($ISBN,$BorrowedCopies,$db_prefix){
	$result = dbquery("UPDATE ".$db_prefix."library_resource SET Resource_BorrowedCopies='$BorrowedCopies' WHERE Resource_ISBN='$ISBN'");
}//function ends here


function UpdateResourceStatus($ResourceCode,$Status,$LastPatronCode,$BorrowCount,$db_prefix){
	$result = dbquery("UPDATE ".$db_prefix."library_resource SET Resource_Status='$Status', Resource_LastPatronCode='$LastPatronCode', Resource_BorrowCount='$BorrowCount' WHERE Resource_Code='$ResourceCode'");
}//function ends here


function QueryPatronInfo($user,$db_prefix){
	$result = dbquery("SELECT * FROM ".$db_prefix."extra_userinfo WHERE extra_userinfo_SiteUserName='$user'");
	return dbarray($result);
}//function ends here

function QueryResources($resourcecode,$db_prefix){
	$result = dbquery("SELECT * FROM ".$db_prefix."library_resource WHERE Resource_Code='$resourcecode'");
	return dbarray($result);
}//function ends here


function QueryISBNCount($ISBN,$db_prefix){
	$result = dbquery("SELECT * FROM ".$db_prefix."library_resource WHERE Resource_ISBN='$ISBN'");
	return dbrows($result);
}//function ends here

function UpdateAvailableCopies($ISBN, $AvailableCopies, $db_prefix){
	$result = dbquery("UPDATE ".$db_prefix."library_resource SET Resource_AvailableCopies='$AvailableCopies' WHERE Resource_ISBN='$ISBN'");
}//function ends here


function QueryUserID($user,$db_prefix){
	$result = dbquery("SELECT user_id FROM ".$db_prefix."users WHERE user_name='$user'");
	$data = dbarray($result);
	$userid = $data['user_id'];
	return $userid;
}//function ends here

function QueryUserAvatar($user,$db_prefix){
	$result = dbquery("SELECT user_avatar FROM ".$db_prefix."users WHERE user_name='$user'");
	$data = dbarray($result);
	$useravatar = $data['user_avatar'];
	return $useravatar;
}//function ends here

function QueryUserPatronCode($user,$db_prefix){
	$result = dbquery("SELECT Patron_Code FROM ".$db_prefix."library_patrons WHERE Patron_SiteUserName='$user'");
	$data = dbarray($result);
	$userid = $data['Patron_Code'];
	return $userid;
}//function ends here

function IncrementPatronBC($patronCode,$BorrowCount,$db_prefix){
	$result = dbquery("UPDATE ".$db_prefix."library_patrons SET Patron_BorrowCount='$BorrowCount' WHERE Patron_Code='$patronCode'");
}//function ends here

function QueryUserEmail($user,$db_prefix){
	$result = dbquery("SELECT user_email FROM ".$db_prefix."users WHERE user_name='$user'");
	$data = dbarray($result);
	$useremail = $data['user_email'];
	return $useremail;
}//function ends here

function cleanArray($array) {
   foreach ($array as $index => $value) {
       if (empty($value)) unset($array[$index]);
   }
	$newMy = array();
		$i = 0;
		foreach ($array as $key => $value) {
		  if (!is_null($value)) {
			$newMy[$i] = $value;
			$i++;
		  }
		}
		   
	   return $newMy;
} //function ends here


function QueryUserFullName($user,$db_prefix){
	$result = dbquery("SELECT extra_userinfo_FirstName, extra_userinfo_MiddleName, extra_userinfo_LastName FROM ".$db_prefix."extra_userinfo WHERE extra_userinfo_SiteUserName='$user'");
	$data = dbarray($result);
	
	if ($data['extra_userinfo_FirstName']<>""){
		$first = $data['extra_userinfo_FirstName'];
	}

	if ($data['extra_userinfo_MiddleName']<>""){
		$middle = $data['extra_userinfo_MiddleName'];
	}

	if ($data['extra_userinfo_LastName']<>""){
		$last = $data['extra_userinfo_LastName'];
	}
	
	$FullName = $first . "&nbsp;" . $middle . "&nbsp;" . $last;
	if ($FullName == "&nbsp;&nbsp;"){
		$FullName = ""; 
	} 
	return $FullName;
}//function ends here


function QueryField($user,$field,$db_prefix){
	$result = dbquery("SELECT ".$field." FROM ".$db_prefix."extra_userinfo WHERE extra_userinfo_SiteUserName='$user'");
	$data = dbarray($result);

	if ($field=="extra_userinfo_StudentsStudying") {
		$result = $data['extra_userinfo_StudentsStudying'];
		return $result;
	} elseif ($field=="extra_userinfo_OtherInfo") {
		$result = $data['extra_userinfo_OtherInfo'];
		return $result;
	} elseif ($field=="extra_userinfo_EmergencyContact") {
		$result = $data['extra_userinfo_EmergencyContact'];
		return $result;
	} elseif ($field=="extra_userinfo_GradeLevel") {
		$result = $data['extra_userinfo_GradeLevel'];
		return $result;
	}
}//function ends here



function sendemail($to_name,$to_email,$from_name,$from_email,$subject,$message,$type,$cc="",$bcc="") {
	
	global $settings,$locale;
	
	$email_to = $to_name." <".$to_email.">";
	$headers = "From: ".$from_name." <".$from_email.">\n";
	$headers .= "Reply-To: ".$from_name." <".$from_email.">\n";
	$headers .= "X-Sender: <".$from_email.">\n";
	$headers .= "X-Mailer: PHP-Mail\n";
	$headers .= "X-MimeOLE: Produced By PHP-Fusion 6\n";
	$headers .= "X-Priority: 3\n";
	$headers .= "X-MSMail-Priority: Normal\n";
	$headers .= "MIME-Version: 1.0\n";
	if ($type == "plain") {
		$headers .= "Content-type: text/plain; charset=".$locale['charset'];
	} else if ($type == "html") {
		$headers .= "Content-type: text/html; charset=".$locale['charset'];
	}
	if ($cc) $headers .= "\n"."Cc: ".$cc;
	if ($bcc) $headers .= "\n"."Bcc: ".$bcc;
	if (mail($email_to, $subject, $message, $headers)) {
		return TRUE;
	} else {
		return FALSE;
	}
}

function createthumbnail($filetype, $origfile, $thumbfile, $new_w, $new_h) {

	global $settings;

	if ($filetype == 1) { $origimage = imagecreatefromgif($origfile); }
	elseif ($filetype == 2) { $origimage = imagecreatefromjpeg($origfile); }
	elseif ($filetype == 3) { $origimage = imagecreatefrompng($origfile); }
	
	$old_x = imagesx($origimage);
	$old_y = imagesy($origimage);
	
	if ($old_x > $new_w || $old_y > $new_h) {
		if ($old_x < $old_y) {
			$thumb_w = round(($old_x * $new_h) / $old_y);
			$thumb_h = $new_h;
		} elseif ($old_x > $old_y) {
			$thumb_w = $new_w;
			$thumb_h = round(($old_y * $new_w) / $old_x);
		} else {
			$thumb_w = $new_w;
			$thumb_h = $new_h;
		}
	} else {
		$thumb_w = $old_x;
		$thumb_h = $old_y;
	}
	
	if ($settings['thumb_compression'] == "gd1") {
		$thumbimage = imagecreate($thumb_w,$thumb_h);
		$result = imagecopyresized($thumbimage, $origimage, 0, 0, 0, 0, $thumb_w, $thumb_h, $old_x, $old_y);
	} else {
		$thumbimage = imagecreatetruecolor($thumb_w,$thumb_h);
		$result = imagecopyresampled($thumbimage, $origimage, 0, 0, 0, 0, $thumb_w, $thumb_h, $old_x, $old_y);
	}
	
	touch($thumbfile);

	if ($filetype == 1) { imagegif($thumbimage, $thumbfile); }
	elseif ($filetype == 2) { imagejpeg($thumbimage, $thumbfile); }
	elseif ($filetype == 3) { imagepng($thumbimage, $thumbfile); }
}
?>